@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
+from .diagnostic_sheets import DiagnosticSheets
+from .raw import Raw
 from .single_cell_features import SingleCellFeatures
 from .single_cell_images import SingleCellImages
 from .standardize_fov_array import StandardizeFOVArray
-from .make_diagnostic_sheet import MakeDiagnosticSheet
 
 __all__ = [
+    "Raw",
     "SingleCellFeatures",
     "StandardizeFOVArray",
     "SingleCellImages",
-    "MakeDiagnosticSheet",
+    "DiagnosticSheets",
 ]
